@@ -130,30 +130,33 @@ def parse(ann_path: str) -> Document:
 
 def fragment_entity(e: Entity) -> Entity:
     e = deepcopy(e)
-    e.text = e.text.strip()
     matches = list(re.finditer(r"\n+", e.text))
     start = 0
     offset = e.start
     spans = []
     fragments = []
     for m in matches:
-        while e.text[start].isspace():
-            start += 1
-        frag_start = offset + start
-        frag_end = offset + m.start()
-        if frag_start != frag_end:
-            spans.append((frag_start, frag_end))
-            fragments.append(e.text[start : m.start()])
+        frag_start = start
+        while e.text[frag_start].isspace():
+            frag_start += 1
+        frag_end = m.start()
+        while e.text[frag_end - 1].isspace():
+            frag_end -= 1
+        if frag_start < e.end and frag_start < frag_end:
+            spans.append((frag_start + offset, frag_end + offset))
+            fragments.append(e.text[frag_start:frag_end])
             start = m.end()
 
-    while e.text[start].isspace():
-        start += 1
-    frag_start = offset + start
-    frag_end = offset + len(e.text)
-
-    if frag_start != frag_end:
-        spans.append((frag_start, frag_end))
-        fragments.append(e.text[start:])
+    frag_start = start
+    if frag_start < len(e.text):
+        while e.text[frag_start].isspace():
+            frag_start += 1
+        frag_end = len(e.text)
+        while e.text[frag_end - 1].isspace():
+            frag_end -= 1
+        if frag_start < e.end and frag_start < frag_end:
+            spans.append((frag_start + offset, frag_end + offset))
+            fragments.append(e.text[frag_start:frag_end])
 
     return Entity(
         id=e.id,
